<?php

namespace Drupal\available_translation\Service;

use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\node\Entity\Node;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * AvailableTranslationService service.
 */
class AvailableTranslationService {

  protected $requestStack;

  /**
   * Constructs an AvailableTranslationService object.
   * @param RequestStack $request_stack
   */
  public function __construct(RequestStack $request_stack) {
    $this->requestStack = $request_stack;
  }

  /**
   * @param string $delimiter
   * @return bool|string
   */
  public function getContent(string $delimiter) {
    $node = $this->requestStack->getCurrentRequest()->get('node');
    if (!($node instanceof Node)) {
      return FALSE;
    }
    $available_languages = $node->getTranslationLanguages();
    $output = "";
    foreach ($available_languages as $language) {
      $link = Link::fromTextAndUrl($language->getName(), Url::fromRoute(
        'entity.node.canonical', ['node' => $node->id()], ['language' => $language]
      ));
      $output .= $link->toString() . $delimiter;
    }
    $output = substr($output, 0, strlen($output) - strlen($delimiter) - 1);

    return $output;
  }
}
